NEMO
====

The National Electricity Market Optimiser (NEMO) is a chronological
dispatch model for testing and optimising different portfolios of
conventional and renewable electricity generation technologies. It was
first developed by Ben Elliston in 2011 at the [Collaboration on
Energy and Environmental Markets](http://www.ceem.unsw.edu.au),
University of New South Wales. NEMO continues to be actively developed
and improved with a growing number of users.
